C***********************************************************************
C***********************************************************************
C	CALCULATES THE INTERFACE COMPOSITION FOR PARABOLLIC GROWTH
C***********************************************************************
C***********************************************************************


C The purpose of this program is getting the column data of composition
C of Ferite solubility line corresponding to the internal pressure of M2C 
C particle, by variating Mo concentration of bulk material. C is fixed.
C The precipitate phase can be chosen. To chose phase, change CLASS of each 
C phase in this program.  
C Alloy composition and phase is in 'shingo3.mpi' file in MTDATA FOLDA.
C Default phase is FCC,BCC,HCP,CEM,M7C3,M23C6 in this program.
C Default component is C,Si,Mn,Cr,Mo,V,Ni,Fe in this program.
C The pressure of HCP phase can be varied
C Copyright Shingo Yamasaki
C University of Cambridge, 10/2001
C
        INCLUDE '/home4/users/guest/mt472obj/DIRUSRAP.FOR'
	IMPLICIT DOUBLE PRECISION(A-H,O-Z),INTEGER(I-N)
	CHARACTER*80 MPI_FILE,DATA_FILE,OUT_FILE
	CHARACTER*80 COMPO_DATA_FILE,FILE_OUT
	INTEGER INIT_PHASE_CLASS,INIT_COMPONENT_CLASS
	INTEGER INIT_PHASE_CLASS,DEFAULT,INIT_NO_OF_COMPONENTS
	INTEGER PRINT_LEVEL
	INTEGER EQUIL_NO_OF_PHASES,ACT_NO_OF_SPECIES
	INTEGER ACT_NO_OF_COMPONENTS,ACT_NO_OF_PHASES
	INTEGER NUMBER_OF_ERRORS
	DOUBLE PRECISION SYSTEM_AMOUNT,PRESSURE,TEMPERATURE
	DOUBLE PRECISION INIT_COMPONENT_AMOUNT
	DOUBLE PRECISION C_at(8),C(8),TEMP,RAD
	DOUBLE PRECISION FC(2500),FMO(2500),FV(2500)
	DOUBLE PRECISION FFE(2500),CC(2500),CMO(2500)
	DOUBLE PRECISION CV(2500),CFE(2500),CMN(2500)
	DOUBLE PRECISION CPC(2500),CPM(2500),CPF(2500)
	DOUBLE PRECISION PRESS,EQFC,EQFMO,AVC,AVMO 
	INTEGER J,L,JJ,K,M
	INTEGER IERR,IMODE
	IN2=40
	OU4=50
	OU5=51




C *********************************************************************** 	
C  Comp_phase_all[max. no of lines, no. of phases, no. of components]
C ***********************************************************************

	IMODE=0

	CALL INITIALISE_MTDATA(IMODE)
	CALL SGUMEN(1)
	CALL SGUMEN(7)

	
	OUT_FILE = 'chem.out'

	MPI_FILE = 'shingo3.mpi'
	FILE_OUT = 'C.out'

	OPEN(UNIT=OU4,FILE=OUT_FILE)
	
c	WRITE(OU4,11)

c11	FORMAT(3x,'Pressure',6x,'C%_Bulk',6x,'Mo%_Bulk',6x,
c&	'C_in_ferrite',5x,'Mo_in_ferrite')


C ********************* CALICURATE START ***************************
	
	IERR=0
	CALL OPEN_MPI_FILE(MPI_FILE,FILE_OUT,IERR)
	CALL SET_PRINT_LEVEL(0)
	IF(IERR .NE. 0) THEN
		WRITE(6,*) 'FAILURE IN MPI FILE READ, ERROR=',IERR
		STOP
	ELSE

C *******************************************************************
C Choose the MATRIX PHASE 1=BCC,2=CEM,3=FCC,4=HCP,5=M7C3,6=M23C6
C *******************************************************************

	WRITE(6,*)'No.of INITIAL PHASE=',INIT_NO_OF_PHASES()
        WRITE(6,*)'PHASE NUMBER'
	WRITE(6,*)'1=HCP,2=BCC,3=CEM,4=FCC,5=M7C3,6=M23C6'
	WRITE(6,*)'PHASE CLASS -2=2-MISC, -1=1-MISC, 0=ABSENT, 1=NORMAL'

	CALL SET_INIT_PHASE_CLASS(1,1)
	CALL SET_INIT_PHASE_CLASS(2,1)
	CALL SET_INIT_PHASE_CLASS(3,0)
	CALL SET_INIT_PHASE_CLASS(4,0)
	CALL SET_INIT_PHASE_CLASS(5,0)
	CALL SET_INIT_PHASE_CLASS(6,0)

	DO 20 I=1,INIT_NO_OF_PHASES()
	WRITE(6,*) 'CLASS OF ',INIT_PHASE_NAME(I),'=',
&	INIT_PHASE_CLASS(I)
20	CONTINUE
	ENDIF

C *********************************************************************
C Classify the state of COMPONENT 1=C,2=Si,3=Mn,4=Cr,5=Mo,6=V,7=Ni,8=Fe
C *********************************************************************
 
	WRITE(6,*) 'No.of INITIAL COMPONENT=',INIT_NO_OF_COMPONENTS()
	WRITE(6,*) 'COMP CLASS -1=FREE, 0=ABSENT, 1=NORMAL, 3=PARA'

	CALL SET_INIT_COMPONENT_CLASS(1,1)
	CALL SET_INIT_COMPONENT_CLASS(2,1)
	CALL SET_INIT_COMPONENT_CLASS(3,1)
	CALL SET_INIT_COMPONENT_CLASS(4,1)
	CALL SET_INIT_COMPONENT_CLASS(5,1)
	CALL SET_INIT_COMPONENT_CLASS(6,1)
	CALL SET_INIT_COMPONENT_CLASS(7,1)
	CALL SET_INIT_COMPONENT_CLASS(8,1)    

	DO 30 I=1,INIT_NO_OF_COMPONENTS()
	WRITE(6,*) 'CLASS OF ',INIT_COMPONENT_NAME(I),'=',
&	INIT_COMPONENT_CLASS(I)
30	CONTINUE

	WRITE(6,*) 'No. OF INITIAL SPECIES=',INIT_NO_OF_SPECIES()


C *********************************************************************** 	
C  Induces variation of alloy composition
C ***********************************************************************

        DO 40 K=0,10
C        AVC=(5.136125D-1/10.D0)*dble(K)
        AVC=5.136125D-1*10.D0**(-3.D0+DBLE(K)*0.3D0)

        DO 50 M=0,10        
C        AVMO=(1.139874D-0/10.D0)*dble(M)
        AVMO=2.D-0*10.D0**(-3.D0+DBLE(M)*0.3D0)

C *********************************************************************
C READ THE wt.% and TEMPERATURE DATA FROM INPUT FILE
C *********************************************************************

	C_at(1)=AVC
	C_at(2)=0.0D0
	C_at(3)=0.0D0
	C_at(4)=0.0D0
	C_at(6)=0.0D0
	C_at(7)=0.0D0
	TEMP=873.0D0


C **************************************************************
C Calculate Setting	
C **************************************************************

        CALL SET_SYSTEM_AMOUNT(100.0D0)
	CALL SET_TEMPERATURE(873.0D0)

C ******************************************************************
C SETTING PRESSURE AND INCREMENT OF CXBINST AND CALCULATE XBINST 
C ******************************************************************
	DO 300 L=1,21
        IF (L.EQ.1) THEN
          PRESS=1.D0
        ELSE
	PRESS = 1.d0/(5.d0*dble(L-1)*1.0d-11) 
        ENDIF
c	DO 300 L=1,41
c	PRESS = 10.0**dble(L-1) 
	CALL SET_PRESSURE(PRESS)
        JJ=0


C ******************************************************************
C CHOOSE THE STEPPED COMPOMENT, INITIAL CONCENTRARION AND INCREMENT 
C ******************************************************************

	DO 100 J=1,41

        IF (L.EQ.1) THEN
          J=20
        ENDIF

	C_at(5)=0.0D0+dble(J)*AVMO/20.0D0

	C_at(8) = 100.0D0-(C_at(2)+C_at(3)+C_at(4)+C_at(5)+C_at(6)+
&       C_at(7)+C_at(1))
	

	WRITE(6,*)'C_at(II)=',(C_at(II),II=1,INIT_NO_OF_COMPONENTS())
	WRITE(*,*)' TEMP [Deg K] : ',TEMP
	WRITE(*,*)'PRESSURE',PRESS

	DO 90 II=1,INIT_NO_OF_COMPONENTS()
	CALL SET_INIT_COMPONENT_AMOUNT(II,C_at(II))
90	CONTINUE

	WRITE(*,*)'CORRECT'

	CALL COMPUTE_EQUILIBRIUM()
	
	WRITE(6,*)'No.of STABLE PHASE=',EQUIL_NO_OF_PHASES()
	WRITE(6,*)'No.of SPECIES=',ACT_NO_OF_SPECIES()

	IF (NUMBER_OF_ERRORS() .NE. 0) THEN
		CALL WRITE_ERROR
	WRITE(6,*)'ERROR2' 
	STOP
	ELSE
	GO TO 95
	END IF

95	IF (EQUIL_NO_OF_PHASES() .EQ. 1) THEN
        IF (L.EQ.1) THEN
	 GOTO 50
        ELSE
         GOTO 100
        ENDIF
	ELSE
	GO TO 115
	END IF


	
	WRITE(6,*) '----------------------'
	WRITE(6,*) '  APPLICATION OUTPUT'
	WRITE(6,*) '----------------------'

C *********************************************************************
C WRITE OUT THE THERMODAINAMIC PROPERTIES OF THE SYSTEM
C *********************************************************************


	WRITE(6,*) 'NUMBER OF STABLE PHASES =',
&	EQUIL_NO_OF_PHASES()
	WRITE(6,*) 'NUMBER OF ACTIVE PHASES =',
&	ACT_NO_OF_PHASES()

115	IF (MASS_IN_PHASE(1,INITIAL) .NE. 0.0D0) THEN
		WRITE(6,*) 'MASS OF ',ACT_PHASE_NAME(1),
&		MASS_IN_PHASE(1,INITIAL)
	END IF

	IF (MASS_IN_PHASE(2,INITIAL) .NE. 0.0D0) THEN
		WRITE(6,*) 'MASS OF ',ACT_PHASE_NAME(2),
&		MASS_IN_PHASE(2,INITIAL)
	END IF


	FC(J)=COMPONENT_X_OF_PHASE(1,2,1)
	FMO(J)=COMPONENT_X_OF_PHASE(5,2,1)
        IF (L.EQ.1) THEN
          EQFC=FC(J)
          EQFMO=FMO(J)
        ENDIF
C	FV(J)=COMPONENT_X_OF_PHASE(6,2,1)
	FFE(J)=COMPONENT_X_OF_PHASE(8,2,1)
	CC(J)=COMPONENT_X_OF_PHASE(1,1,1)
	CMO(J)=COMPONENT_X_OF_PHASE(5,1,1)
C	CV(J)=COMPONENT_X_OF_PHASE(6,1,1)
	CFE(J)=COMPONENT_X_OF_PHASE(8,1,1)
	CMN(J)=COMPONENT_X_OF_PHASE(3,1,1)

        CPC(J)=PARTIAL_SYSTEM_GIBBS_ENERGY(1)
        CPM(J)=PARTIAL_SYSTEM_GIBBS_ENERGY(5)
        CPF(J)=PARTIAL_SYSTEM_GIBBS_ENERGY(8)
	 
        IF ((FC(J).GT.(0.9D0*EQFC)).AND.(FC(J).LT.(1.1D-2*AVC)).AND.
&         (FMO(J).GT.(0.9D0*EQFMO)).AND.(FMO(J).LT.(1.1D-2*AVMO))) THEN
            WRITE(OU4,210) AVC,AVMO,PRESS,FC(J),FMO(J),CC(J),
&                          CMO(J),CPC(J),CPM(J),CPF(J)
          JJ=JJ+1
        ELSE
          IF (JJ.EQ.1) THEN
            WRITE(OU4,210) AVC,AVMO,PRESS,FC(J),FMO(J),CC(J),
&                          CMO(J),CPC(J),CPM(J),CPF(J)
            JJ=JJ+1 
          ENDIF
        ENDIF

        IF (L.EQ.1) THEN
          GOTO 300
        ENDIF

100	CONTINUE
300	CONTINUE

50       CONTINUE
40       CONTINUE



210	FORMAT(1x,F12.10,4x,F12.10,4x,F14.1,4x,F14.10,4x,F14.10,4x,
&              F14.10,4x,F14.10,4x,
&              F14.6,4x,F14.6,4x,F14.6)

        CLOSE(OU4)
	
500	STOP
	END
